# 웹소켓 연결

## 디스코도에 연결하기

### 연결

#### 웹소켓 헤더

|이름|자료형|설명|
|---|----|-----------|
|Authorization|문자열|디스코도 서버의 비밀번호|

헤더가 누락되거나 일치하지 않는다면, 클라이언트는 FORBIDDEN 이벤트를 수신합니다.

#### FORBIDDEN 예재

```json
{
    "op": "FORBIDDEN",
    "d": "연결이 거부된 사유"
}
```

연결에 성공하면, 클라이언트는 Heartbeat 주기가 담긴 HELLO 이벤트를 수신합니다.

#### HELLO 예제

```json
{
    "op": "HELLO",
    "d": {
        "heartbeat_interval": 15.0
    }
}
```

### Heartbeat 전송

HELLO 이벤트를 수신한 이후에는, 클라이언트는 연결이 종료될때까지 매 `heartbeat_interval`초 마다 HEARTBEAT 페이로드를 전송하기 시작해야 합니다.

#### HEARTBEAT 페이로드 예제

```json5
{
    "op": "HEARTBEAT",
    "d": 1596417937 // 타임스탬프
}
```

페이로드 데이터 (`d`)는 nullable입니다, 서버는 그것을 재전송합니다.

#### HEARTBEAT_ACK 예제

```json5
{
    "op": "HEARTBEAT_ACK",
    "d": 1596417937 // 타임스탬프
}
```

### 식별

클라이언트는 오디오 매니저를 설정하기 위해서 IDENTIFY 페이로드를 전송해야 합니다.

#### IDENTIFY 페이로드 예제

```json
{
    "op": "IDENTIFY",
    "d": {
        "user_id": "봇 ID"
    }
}
```

### 복원

VC_TIMEOUT전에 같은 유저 아이디가 연결된다면, 매니저가 복원됩니다.

#### RESUMED 예제

```json5
{
    "op": "RESUMED",
    "d": {
        "voice_clients": [
            [0, 0] // guild_id, voicechannel_id(can be null)
        ]
    }
}
```

클라이언트가 RESUMED 이벤트를 수신한다면, 음성 채널에 재연결해야합니다.

### 연결 해제

연결이 종료된다면, 서버는 매니저와 재생중인 소스들을 정리합니다.
